@@ -532,7 +532,7 @@ did = ? and queue = 3 and due <= ? limit ?""",
                 resched = self._resched(card)
                 if 'mult' in conf and resched:
                     # review that's lapsed
-                    card.ivl = max(1, card.ivl*conf['mult'])
+                    card.ivl = max(1, conf['minInt'], card.ivl*conf['mult'])
                 else:
                     # new card; no ivl adjustment
                     pass
@@ -1188,7 +1188,7 @@ To study outside of the normal schedule, click the Custom Study button below."""
         "Return the next interval for CARD as a string."
         ivl = self.nextIvl(card, ease)
         if not ivl:
-            return ""
+            return _("(end)")
         s = fmtTimeSpan(ivl, short=short)
         if ivl < self.col.conf['collapseTime']:
             s = "<"+s
