@@ -296,15 +296,19 @@ class StatusDelegate(QItemDelegate):
 
     def __init__(self, browser, model):
         QItemDelegate.__init__(self, browser)
+        self.browser = browser
         self.model = model
 
     def paint(self, painter, option, index):
+        self.browser.mw.progress.blockUpdates = True
         try:
             c = self.model.getCard(index)
         except:
             # in the the middle of a reset; return nothing so this row is not
             # rendered until we have a chance to reset the model
             return
+        finally:
+            self.browser.mw.progress.blockUpdates = True
         col = None
         if c.note().hasTag("Marked"):
             col = COLOUR_MARKED
@@ -1293,6 +1297,8 @@ update cards set usn=?, mod=?, did=? where id in """ + scids,
 
     def onNote(self):
         self.editor.focus()
+        self.editor.web.setFocus()
+        self.editor.web.eval("focusField(0);")
 
     def onTags(self):
         self.form.tree.setFocus()
